==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Shape/ShapePolygonCP/ts/ShapePolygonCP_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LinePolygonCP</name>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <source>Corner point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Punkt narożny</translation>
    </message>
    <message>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation type="obsolete">Zrobione</translation>
    </message>
    <message>
        <source>Corners:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Rogi:</translation>
    </message>
    <message>
        <source>Pol&amp;ygon (Center, Point)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Polygon (Center Point)</translation>
    </message>
    <message>
        <source>Draw regular polygon from center and corner point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Rysowanie wielokąta foremnego od punktu środkowego i narożny</translation>
    </message>
</context>
<context>
    <name>ShapePolygonCP</name>
    <message>
        <location filename="../ShapePolygonCP.js" line="+58"/>
        <source>Center</source>
        <translation type="unfinished">Wyśrodkuj</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Corner point</source>
        <translation type="unfinished">Punkt narożny</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation type="unfinished">Zrobione</translation>
    </message>
    <message>
        <location filename="../ShapePolygonCP.ui" line="+17"/>
        <source>Corners:</source>
        <translation type="unfinished">Rogi:</translation>
    </message>
    <message>
        <source>Pol&amp;ygon (Center, Point)</source>
        <translation type="obsolete">Polygon (Center Point)</translation>
    </message>
    <message>
        <location filename="../ShapePolygonCPInit.js" line="+2"/>
        <source>Pol&amp;ygon (Center, Corner)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw regular polygon from center and corner point</source>
        <translation type="unfinished">Rysowanie wielokąta foremnego od punktu środkowego i narożny</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Shape/ShapePolygonCP/ts/ShapePolygonCP_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LinePolygonCP</name>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <source>Corner point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Punkt narożny</translation>
    </message>
    <message>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation type="obsolete">Zrobione</translation>
    </message>
    <message>
        <source>Corners:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Rogi:</translation>
    </message>
    <message>
        <source>Pol&amp;ygon (Center, Point)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Polygon (Center Point)</translation>
    </message>
    <message>
        <source>Draw regular polygon from center and corner point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Rysowanie wielokąta foremnego od punktu środkowego i narożny</translation>
    </message>
</context>
<context>
    <name>ShapePolygonCP</name>
    <message>
        <location filename="../ShapePolygonCP.js" line="+58"/>
        <source>Center</source>
        <translation>Środek</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Corner point</source>
        <translation>Punkt narożnika</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location filename="../ShapePolygonCP.ui" line="+17"/>
        <source>Corners:</source>
        <translation>Liczba narożników:</translation>
    </message>
    <message>
        <source>Pol&amp;ygon (Center, Point)</source>
        <translation type="obsolete">Polygon (Center Point)</translation>
    </message>
    <message>
        <location filename="../ShapePolygonCPInit.js" line="+2"/>
        <source>Pol&amp;ygon (Center, Corner)</source>
        <translation>Wi&amp;elokąt (środek, narożnik)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw regular polygon from center and corner point</source>
        <translation>Rysuje wielokąt foremny ze środka i przez punkt narożnika</translation>
    </message>
</context>
</TS>
